@@ -29,11 +29,11 @@ class MachineLearningModel(object):
         #     logger.error(message)
         #     raise FileNotFoundError(message)
         package_dir = os.path.dirname(os.path.abspath(__file__))
-        thefile = os.path.join(package_dir,'TrainedModel_c++.ann')
-        print(package_dir)
+        thefile = os.path.join(package_dir,'../../ml/model/TrainedModel_c++.ann')
+        print(thefile)
         # mypath = path("tqatest.ml.model", "TrainedModel_c++.ann")
 
-        # self.load_model(str(mypath))
+        self.load_model(thefile)
     
     def load_model(self, mypath : str):
         self.model = annhub.ANNHUB(int(MODEL_ID))
